@@ -33,12 +33,13 @@ foreach i {
   {"set-var pan" "get-var pan"}
   {"set-var fps" "get-var fps"}
 	{"set-var ips" "get-var ips"}
-  {"set-var drone_handle_size" "get-var drone_handle_size"}
+  {"set-var drone_wand_dist" "get-var drone_wand_dist"}
   {"set-var trail_length" "get-var trail_length"}
   {"set-var voice_volume" "get-var voice_volume"}
   {"set-var sustain" "get-var sustain"}
   {"set-var instrument" "get-var instrument"}
 	{"set-var midi_in" "get-var midi_in"}
+	{"set-var stepz" "format {{%s}} [get-var stepz]"}
   {"set-scope left" "format {{%s}} [get-scope left]"}
   {"set-scope right" "format {{%s}} [get-scope right]"}
   {"set-var show_parameters" "get-var show_parameters"}
@@ -52,6 +53,7 @@ foreach i {
 	{"set-var mixing_time" "get-var mixing_time"}
 	{"set-var binaural_drones.master_volume" "get-var binaural_drones.master_volume"}
 	{"set-var binaural_drones.justification" "get-var binaural_drones.justification"}
+  {"set-var gab-time-variance" "format {{%s}} [get-var gab-time-variance]"}
   } {
   set setc [lindex $i 0]
   set getc [lindex $i 1]
